==> coreinfo-2.7.0.tar.gz: coreinfo-v2.7.0/coreinfo.cpp <==
/*
    *
    * This file is a part of CoreInfo.
    * A file information viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 2 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#include <QMimeData>
#include <QTextBrowser>
#include <QFileDialog>

#include "configtreetext.h"
#include <cprime/themefunc.h>
#include <cprime/infofunc.h>

#include "coreinfo.h"
#include "ui_coreinfo.h"


coreinfo::coreinfo(QWidget *parent) : QWidget(parent), ui(new Ui::coreinfo)
{
    ui->setupUi(this);

    QPalette pltt(palette());
    pltt.setColor(QPalette::Base, Qt::transparent);
    setPalette(pltt);

    C = new Core();

    loadSettings();
    startSetup();
}

coreinfo::~coreinfo()
{
    delete ui;
}

/**
 * @brief Setup ui elements
 */
void coreinfo::startSetup()
{
    // set window size
    if (touch) {
        this->setWindowState(Qt::WindowMaximized);
    } else {
        this->resize(800, 500);
    }

    connect(ui->addFiles, SIGNAL(clicked()), this, SLOT(openFileDialog()));
}

/**
 * @brief Loads application settings
 */
void coreinfo::loadSettings()
{
    //touch mode
    touch = sm->value("CoreApps", "TouchMode");
}


void coreinfo::openFiles(QStringList fileNames)
{
    //Configuring
    if (fileNames.count() == 0) {
        CPrime::InfoFunc::messageEngine("No file found.\nPlease enter some valid file path.", CPrime::MessageType::Info, this);
        return;
    }

    ui->page->setCurrentIndex(1);

    for (int i = 0; i < fileNames.count(); i++) {
        fileNames[i] = QDir::toNativeSeparators(fileNames[i]);
    }

    this->setWindowTitle(QFileInfo(fileNames[0]).fileName() + " - CoreInfo");

    // For opening multiple files in one view
//    C->Menu_File_Open_Files_Begin(true, false);
//    for (int Pos=0; Pos<fileNames.size(); Pos++){
//        C->Menu_File_Open_Files_Continue(QString2wstring(fileNames[Pos]));
//    }

    // For opening single file
//    C->Menu_File_Open_File(QString2wstring(fileNames[ 0 ]));

    // For opening multiple files in different view
    for (int i = 0; i < fileNames.count(); i++) {
        C->Menu_File_Open_File(QString2wstring(fileNames[i]));
        refreshDisplay();
    }
}

void coreinfo::refreshDisplay()
{
    // Show info in QTreeWidget
    C->Menu_View_Tree();

    // View item
    QWidget *wid = new QWidget;
    QHBoxLayout *layout = new QHBoxLayout;
    layout->addWidget(showTreeView(true));
    wid->setLayout(layout);

    ui->container->addWidget(wid);
}

QDir coreinfo::getCommonDir(Core *C) // Get the common directory among all files
{
    QList<QStringList> list;
    QStringList dirName;
    unsigned fileCount = static_cast<unsigned>(C->Count_Get());

    if (fileCount == 0) {
        return QDir::home();
    }

    for (unsigned filePos = 0; filePos < fileCount; filePos++) {
        list.append(QDir::toNativeSeparators(wstring2QString(C->Get(filePos, Stream_General, 0, __T("CompleteName")))).split(QDir::separator()));
    }

    if (!list.isEmpty())
        for (int i = 0; i < list[0].size() - 1; ++i) {
            int j;

            for (j = 1; (j < list.size()) && (list[j].size() > i); ++j) {
                if (list[j][i] != list[0][i]) {
                    break;
                }
            }

            if ((j < list.size()) && (list[j].size() >= i)) {
                break;
            } else {
                dirName.append(list[0][i]);
            }
        }

    QDir dir(dirName.join(QDir::separator()));
    return dir;
}

QTreeWidget *coreinfo::showTreeView(bool completeDisplay)
{
    QTreeWidget *treeWidget = new QTreeWidget();
    //treeWidget->setHeaderHidden(true);
    treeWidget->setColumnCount(2);
    treeWidget->setFrameShape(QFrame::NoFrame);


    QStringList headers = QStringList("key");
    headers.append("value");
    treeWidget->setHeaderLabels(headers);
    unsigned fileCount = static_cast<unsigned>(C->Count_Get());

    //QDir dir = getCommonDir(C);

    for (size_t filePos = 0; filePos < fileCount; filePos++) {

        // For each file
        //QTreeWidgetItem* treeItem = new QTreeWidgetItem(treeWidget,QStringList(shortName(dir,wstring2QString(C->Get(filePos, Stream_General, 0, __T("CompleteName"))))));
        //treeWidget->addTopLevelItem(treeItem);

        for (int streamKind = static_cast<int>(Stream_General); streamKind < static_cast<int>(Stream_Max); streamKind++) {
            // For each type of flow
            QString StreamKindText = wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), 0, __T("StreamKind/String"), Info_Text));
            size_t StreamsCount = C->Count_Get(filePos, static_cast<stream_t>(streamKind));

            for (size_t streamPos = Stream_General; streamPos < StreamsCount; streamPos++) {
                // For each stream
                QString A = StreamKindText;
                QString B = wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, __T("StreamKindPos"), Info_Text));

                if (!B.isEmpty()) {
                    A += " #" + B;
                }

                // For each file
                //QTreeWidgetItem* node = new QTreeWidgetItem(treeItem,QStringList(A));
                //treeItem->addChild(node);

                // For one file
                QTreeWidgetItem *node = new QTreeWidgetItem(treeWidget, QStringList(A));
                treeWidget->addTopLevelItem(node);
                QMap<QString, QString> listL;

                if (ConfigTreeText::getIndex() == 0) {
                    size_t ChampsCount = C->Count_Get(filePos, static_cast<stream_t>(streamKind), streamPos);

                    for (size_t Champ_Pos = 0; Champ_Pos < ChampsCount; Champ_Pos++) {
                        if ((completeDisplay || C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Options)[InfoOption_ShowInInform]
                                == __T('Y')) && C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Text) != __T("")) {
                            QString A = wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Text));
                            A += wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Measure_Text));

                            QString D = wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Name_Text));

                            if (D.isEmpty()) {
                                D = wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Name));    //Texte n'existe pas
                            }

//                            QStringList sl = QStringList(D);
//                            sl.append(A);
                            listL[D] = A;


                        }
                    }
                } else {
//                    foreach(QString field, ConfigTreeText::getConfigTreeText()->getFields(streamKind)) {
//                        QString A=wstring2QString(C->Get(filePos,static_cast<stream_t>(streamKind), streamPos, QString2wstring(field), Info_Text));
//                        A+=wstring2QString(C->Get(filePos,static_cast<stream_t>(streamKind), streamPos, QString2wstring(field), Info_Measure_Text));
//                        QString B=wstring2QString(C->Get(filePos,static_cast<stream_t>(streamKind), streamPos, QString2wstring(field), Info_Name_Text));
//                        if (B.isEmpty())
//                            B=wstring2QString(C->Get(filePos,static_cast<stream_t>(streamKind), streamPos, QString2wstring(field), Info_Name));
//                        QStringList sl = QStringList(B);
//                        sl.append(A);
//                        node->addChild(new QTreeWidgetItem(node,sl));
//                    }
                }

                QStringList k = listL.keys();

                for (int i = 0; i < listL.count(); i++) {
                    QString key = k[i];
                    node->addChild(new QTreeWidgetItem(node, QStringList() << key << listL.value(key)));
                }
            }
        }
    }

    if (C->Count_Get() <= 1) {
        treeWidget->expandAll();
    }

    treeWidget->resizeColumnToContents(0);
    return treeWidget;
}

QString coreinfo::shortName(QDir d, QString name)
{
    //Elminating unuseful info from filenames
    return d.relativeFilePath(name);
}

void coreinfo::openFileDialog()
{
    QStringList list = QFileDialog::getOpenFileNames(this, "Add files", QDir::currentPath(), "*");

    if (list.count() > 0) {
        openFiles(list);
    }
}

==> coreinfo-2.8.0.tar.gz: coreinfo-v2.8.0/coreinfo.cpp <==
/*
    *
    * This file is a part of CoreInfo.
    * A file information viewer for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 2 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, write to the Free Software
    * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
    * MA 02110-1301, USA.
    *
*/


#include <QMimeData>
#include <QTextBrowser>
#include <QFileDialog>

#include "configtreetext.h"
#include <cprime/themefunc.h>
#include <cprime/infofunc.h>

#include "coreinfo.h"
#include "ui_coreinfo.h"


coreinfo::coreinfo(QWidget *parent) : QWidget(parent), ui(new Ui::coreinfo)
{
    ui->setupUi(this);

    QPalette pltt(palette());
    pltt.setColor(QPalette::Base, Qt::transparent);
    setPalette(pltt);

    C = new Core();

    loadSettings();
    startSetup();
}

coreinfo::~coreinfo()
{
    delete ui;
}

/**
 * @brief Setup ui elements
 */
void coreinfo::startSetup()
{
    // set window size
    if (touch) {
        this->setWindowState(Qt::WindowMaximized);
    } else {
        this->resize(800, 500);
    }

    ui->page->setCurrentIndex(0);
    connect(ui->addFiles, SIGNAL(clicked()), this, SLOT(openFileDialog()));
}

/**
 * @brief Loads application settings
 */
void coreinfo::loadSettings()
{
    //touch mode
    touch = sm->value("CoreApps", "TouchMode");
}


void coreinfo::openFiles(QStringList fileNames)
{
    //Configuring
    if (fileNames.count() == 0) {
        CPrime::InfoFunc::messageEngine("CoreInfo", "coreinfo", "No file found", "Please enter some valid file path.",  this);
        return;
    }

    ui->page->setCurrentIndex(1);

    for (int i = 0; i < fileNames.count(); i++) {
        fileNames[i] = QDir::toNativeSeparators(fileNames[i]);
    }

    this->setWindowTitle(QFileInfo(fileNames[0]).fileName() + " - CoreInfo");

    // For opening multiple files in one view
//    C->Menu_File_Open_Files_Begin(true, false);
//    for (int Pos=0; Pos<fileNames.size(); Pos++){
//        C->Menu_File_Open_Files_Continue(QString2wstring(fileNames[Pos]));
//    }

    // For opening single file
//    C->Menu_File_Open_File(QString2wstring(fileNames[ 0 ]));

    // For opening multiple files in different view
    for (int i = 0; i < fileNames.count(); i++) {
        C->Menu_File_Open_File(QString2wstring(fileNames[i]));
        refreshDisplay();
    }
}

void coreinfo::refreshDisplay()
{
    // Show info in QTreeWidget
    C->Menu_View_Tree();

    // View item
    QWidget *wid = new QWidget;
    QHBoxLayout *layout = new QHBoxLayout;
    layout->addWidget(showTreeView(true));
    wid->setLayout(layout);

    ui->container->addWidget(wid);
}

QDir coreinfo::getCommonDir(Core *C) // Get the common directory among all files
{
    QList<QStringList> list;
    QStringList dirName;
    unsigned fileCount = static_cast<unsigned>(C->Count_Get());

    if (fileCount == 0) {
        return QDir::home();
    }

    for (unsigned filePos = 0; filePos < fileCount; filePos++) {
        list.append(QDir::toNativeSeparators(wstring2QString(C->Get(filePos, Stream_General, 0, __T("CompleteName")))).split(QDir::separator()));
    }

    if (!list.isEmpty())
        for (int i = 0; i < list[0].size() - 1; ++i) {
            int j;

            for (j = 1; (j < list.size()) && (list[j].size() > i); ++j) {
                if (list[j][i] != list[0][i]) {
                    break;
                }
            }

            if ((j < list.size()) && (list[j].size() >= i)) {
                break;
            } else {
                dirName.append(list[0][i]);
            }
        }

    QDir dir(dirName.join(QDir::separator()));
    return dir;
}

QTreeWidget *coreinfo::showTreeView(bool completeDisplay)
{
    QTreeWidget *treeWidget = new QTreeWidget();
    //treeWidget->setHeaderHidden(true);
    treeWidget->setColumnCount(2);
    treeWidget->setFrameShape(QFrame::NoFrame);


    QStringList headers = QStringList("key");
    headers.append("value");
    treeWidget->setHeaderLabels(headers);
    unsigned fileCount = static_cast<unsigned>(C->Count_Get());

    //QDir dir = getCommonDir(C);

    for (size_t filePos = 0; filePos < fileCount; filePos++) {

        // For each file
        //QTreeWidgetItem* treeItem = new QTreeWidgetItem(treeWidget,QStringList(shortName(dir,wstring2QString(C->Get(filePos, Stream_General, 0, __T("CompleteName"))))));
        //treeWidget->addTopLevelItem(treeItem);

        for (int streamKind = static_cast<int>(Stream_General); streamKind < static_cast<int>(Stream_Max); streamKind++) {
            // For each type of flow
            QString StreamKindText = wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), 0, __T("StreamKind/String"), Info_Text));
            size_t StreamsCount = C->Count_Get(filePos, static_cast<stream_t>(streamKind));

            for (size_t streamPos = Stream_General; streamPos < StreamsCount; streamPos++) {
                // For each stream
                QString A = StreamKindText;
                QString B = wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, __T("StreamKindPos"), Info_Text));

                if (!B.isEmpty()) {
                    A += " #" + B;
                }

                // For each file
                //QTreeWidgetItem* node = new QTreeWidgetItem(treeItem,QStringList(A));
                //treeItem->addChild(node);

                // For one file
                QTreeWidgetItem *node = new QTreeWidgetItem(treeWidget, QStringList(A));
                treeWidget->addTopLevelItem(node);
                QMap<QString, QString> listL;

                if (ConfigTreeText::getIndex() == 0) {
                    size_t ChampsCount = C->Count_Get(filePos, static_cast<stream_t>(streamKind), streamPos);

                    for (size_t Champ_Pos = 0; Champ_Pos < ChampsCount; Champ_Pos++) {
                        if ((completeDisplay || C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Options)[InfoOption_ShowInInform]
                                == __T('Y')) && C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Text) != __T("")) {
                            QString A = wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Text));
                            A += wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Measure_Text));

                            QString D = wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Name_Text));

                            if (D.isEmpty()) {
                                D = wstring2QString(C->Get(filePos, static_cast<stream_t>(streamKind), streamPos, Champ_Pos, Info_Name));    //Texte n'existe pas
                            }

//                            QStringList sl = QStringList(D);
//                            sl.append(A);
                            listL[D] = A;


                        }
                    }
                } else {
//                    foreach(QString field, ConfigTreeText::getConfigTreeText()->getFields(streamKind)) {
//                        QString A=wstring2QString(C->Get(filePos,static_cast<stream_t>(streamKind), streamPos, QString2wstring(field), Info_Text));
//                        A+=wstring2QString(C->Get(filePos,static_cast<stream_t>(streamKind), streamPos, QString2wstring(field), Info_Measure_Text));
//                        QString B=wstring2QString(C->Get(filePos,static_cast<stream_t>(streamKind), streamPos, QString2wstring(field), Info_Name_Text));
//                        if (B.isEmpty())
//                            B=wstring2QString(C->Get(filePos,static_cast<stream_t>(streamKind), streamPos, QString2wstring(field), Info_Name));
//                        QStringList sl = QStringList(B);
//                        sl.append(A);
//                        node->addChild(new QTreeWidgetItem(node,sl));
//                    }
                }

                QStringList k = listL.keys();

                for (int i = 0; i < listL.count(); i++) {
                    QString key = k[i];
                    node->addChild(new QTreeWidgetItem(node, QStringList() << key << listL.value(key)));
                }
            }
        }
    }

    if (C->Count_Get() <= 1) {
        treeWidget->expandAll();
    }

    treeWidget->resizeColumnToContents(0);
    return treeWidget;
}

QString coreinfo::shortName(QDir d, QString name)
{
    //Elminating unuseful info from filenames
    return d.relativeFilePath(name);
}

void coreinfo::openFileDialog()
{
    QStringList list = QFileDialog::getOpenFileNames(this, "Add files", QDir::currentPath(), "*");

    if (list.count() > 0) {
        openFiles(list);
    }
}
